#!/usr/bin/env python

from ncclient import manager

import time

def connect(host, port, user, password):
    conn = manager.connect(host=host,
            port=port,
            username=user,
            password=password,
            timeout=10,
            device_params = {'name':'junos'},
            hostkey_verify=False)

    result = conn.reboot()
    reboot_nodes = result.xpath('request-reboot-results/request-reboot-status')
    if reboot_nodes:
        reboot_time = result.xpath('request-reboot-results/request-reboot-status/@reboot-time')[0]
        if 'Shutdown NOW' in reboot_nodes[0].text:
            print 'Rebooted at:', time.ctime(int(reboot_time))

if __name__ == '__main__':
    connect('router', 830, 'netconf', 'juniper!')



#!/usr/bin/env python

from ncclient import manager


def connect(host, port, user, password, source):
    conn = manager.connect(host=host,
            port=port,
            username=user,
            password=password,
            timeout=10,
            device_params = {'name':'junos'},
            hostkey_verify=False)

    result_xml = conn.get_configuration(format='xml')

    # xpath starts-with
    ge_configs = result_xml.xpath('configuration/interfaces/interface/name[starts-with(text(), "ge-")]')
    for i in ge_configs:
        print i.tag, i.text

    # xpath re:match
    ge_configs = result_xml.xpath('configuration/interfaces/interface/name[re:match(text(), "ge")]')
    for i in ge_configs:
        print i.tag, i.text

    # xpath contains
    ge_configs = result_xml.xpath('configuration/interfaces/interface/name[contains(text(), "ge-")]')
    for i in ge_configs:
        print i.tag, i.text

    # xpath match on text
    ge_configs = result_xml.xpath('configuration/interfaces/interface/name[text()="ge-0/0/0"]')
    for i in ge_configs:
        print i.tag, i.text

    # xpath match on text - alternative (wildcards not permitted)
    ge_configs = result_xml.xpath('configuration/interfaces/interface[name="ge-0/0/0"]')
    for i in ge_configs:
        print i.xpath('name')[0].tag, i.xpath('name')[0].text


if __name__ == '__main__':
    connect('router', 830, 'netconf', 'juniper!', 'candidate')



# Copyright 2009 Shikhar Bhushan
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from errors import OperationError, TimeoutExpiredError, MissingCapabilityError
from rpc import RPC, RPCReply, RPCError, RaiseMode

# rfc4741 ops
from retrieve import Get, GetConfig, GetSchema, GetReply, Dispatch
from edit import EditConfig, CopyConfig, DeleteConfig, Validate, Commit, DiscardChanges
from session import CloseSession, KillSession
from lock import Lock, Unlock, LockContext
# others...
from flowmon import PoweroffMachine, RebootMachine

__all__ = [
    'RPC',
    'RPCReply',
    'RPCError',
    'RaiseMode',
    'Get',
    'GetConfig',
    'GetSchema',
    'Dispatch',
    'GetReply',
    'EditConfig',
    'CopyConfig',
    'Validate',
    'Commit',
    'DiscardChanges',
    'DeleteConfig',
    'Lock',
    'Unlock',
    'PoweroffMachine',
    'RebootMachine',
]



#!/usr/bin/env python

from ncclient import manager
from ncclient.xml_ import *

def connect(host, port, user, password, source):
    conn = manager.connect(host=host,
            port=port,
            username=user,
            password=password,
            timeout=600,
            device_params = {'name':'junos'},
            hostkey_verify=False)

    rpc = """
    <get-xnm-information>
        <type>xml-schema</type>
        <namespace>junos-configuration</namespace>
    </get-xnm-information>"""

    result = conn.rpc(rpc)
    fh = open('schema.txt', 'w')
    fh.write(result.tostring)
    fh.close()



if __name__ == '__main__':
    connect('router', 830, 'netconf', 'juniper!', 'candidate')
